Learn R Programming

snplinkage (version 1.2.0)

gdata_add_gene_annots_aim_example: gdata_add_gene_annots_aim_example

Description

Add ancestry informative markers gene annotations to Genotype Data object. Convenience function for the vignette to avoid querying biomaRt on build.

Usage

gdata_add_gene_annots_aim_example(gdata, aim_idxs)

Value

Genotype Data object

Arguments

gdata

Genotype Data object

aim_idxs

AIM indexes in the example Genotype data object