To query gene names of SNPs, it is necessary to retrieve two objects using biomaRt::useMart. First, the object required to map SNP rs identifiers to ENSEMBL identifiers. Second, the object required to map ENSEMBL identifiers to common gene names. The function returns a list of two slots named snpmart and ensembl corresponding to each one, respectively. Once obtained it is saved to a local file.
get_biomart_metadb(
filepath = extdata_filepath("bmart_meta.rds"),
host = "https://grch37.ensembl.org"
)List of slots snpmart and ensembl as detailed above
Path to save the biomaRt objects
BiomaRt Ensembl host, by default https://grch37.ensembl.org