Print information about quality control performed by the snprelate_qc function.
print_qc_as_tex_table(
gdata_qc,
label = "qc",
caption = paste("Quality control and feature selection of the subset of the",
"human genome diversity project dataset.")
)Prints knitr::kable object using cat
Genotype Data object object returned by snprelate_qc
Label of the Tex table
Caption of the Tex table