Wrapper over SNPRelate::snpgdsSNPRateFreq
snprelate_allele_frequencies(
gdata,
snps_idx = NULL,
scans_idx = NULL,
quiet = FALSE
)A data frame of snps_idx, snps_ids, allele1, allele2, maf, missing where allele1 and allele2 are the rates of the alleles, and maf the minimum of the 2. Missing is the missing rate. N.B: the allele rates are computed on the non missing genotypes, i.e. their sum equals 1.
A GenotypeData object
Vector of snps indices
Vector of scans indices
Whether to be quiet