Creates a gtable of a linkage disequilibrium, chromosomic positions, and association scores ggplots.
gtable_ld_associations(
df_assocs,
df_ld,
pvalue_colname = "pvalues",
labels_colname = "probe_id",
n_labels = 5,
diamonds = nrow(df_assocs) gtable
SNP annotation data frame with columns chromosome, position, and as specified by parameters pvalue_colname and optionally labels_colname.
Data frame with columns SNP_A, SNP_B, and R2, as returned by the snprelate_ld function.
Column name of df_snp with association values
Optional column name of df_snp with labels. Set NULL to remove labels.
Number of labels of most associated SNPs to display.
Should the values be displayed as diamonds or points ? Default is TRUE for up to 40 SNPs.
Add a linked area to associations points. Default same as diamonds.
Point size for ggplot_ld, ignored if diamonds is TRUE.
Colors of SNPs
Passed to ggplot_associations